# -*- coding: utf-8 -*-

import numpy as np


g = 9.80665

Omega = 2 * np.pi / (24 * 3600 * 0.99726966323716)

gamma = 6.49 / 1000
gammad = 9.80 / 1000
cv = 718.0
cp = 1005.0
Rs = 287
miu = 1.72e-1
M = 0.02896968 # molar mass of dry air, 0.0289644 kg/mol

T0 = 298.16
R0 = 8.314462618 # Universal gas constant
rao0 = 1.2252256827617731

niu = 1.85e-5 # kinematic viscosity of air in 25 degree C
kappa = 1.9e-5 # thermal diffusivity of air in 300K

SunConst = 1366

StefanBoltzmann = 0.0000000567

WaterHeatCapacity = 4185.5
RockHeatCapacity = 840

WaterDensity = 1000
IceDensity = 916.7
RockDensity = 2650

LatenHeatIce = 334
LatenHeatWater = 2264.705



# -*- coding: utf-8 -*-


def norm_gpt(x):
    min, max = -10000, 500000
    return (x - min) / (max - min)


def norm_tmp(x):
    min, max = 173, 373
    return (x - min) / (max - min)


def norm_shm(x):
    x = x * (x > 0)
    min, max = 0, 0.1
    return (x - min) / (max - min)


def norm_rhm(x):
    x = x * (x > 0)
    min, max = 0.0, 200.0
    return (x - min) / (max - min)


def norm_u(x):
    min, max = -250.0, 250.0
    return (x - min) / (max - min)


def norm_v(x):
    min, max = -250.0, 250.0
    return (x - min) / (max - min)


def norm_tisr(tisr):
    return tisr / 5500000.0


def norm_tcc(tcc):
    return tcc


def denorm_gpt(x):
    return 510000 * x - 10000


def denorm_tmp(x):
    return 173 + 200.0 * x


def denorm_shm(x):
    return 0.1 * x


def denorm_rhm(x):
    return 200.0 * x


def denorm_u(x):
    return x * 500 - 250.0


def denorm_v(x):
    return x * 500 - 250.0


def denorm_tisr(tisr):
    return tisr * 5500000.0


def denorm_tcc(tcc):
    return tcc


normalizors = {
    'geopotential': norm_gpt,
    'temperature': norm_tmp,
    'specific_humidity': norm_shm,
    'relative_humidity': norm_rhm,
    'u_component_of_wind': norm_u,
    'v_component_of_wind': norm_v,
    'toa_incident_solar_radiation': norm_tisr,
    'total_cloud_cover': norm_tcc,
    '2m_temperature': norm_tmp,
}


denormalizors = {
    'geopotential': denorm_gpt,
    'temperature': denorm_tmp,
    'specific_humidity': denorm_shm,
    'relative_humidity': denorm_rhm,
    'u_component_of_wind': denorm_u,
    'v_component_of_wind': denorm_v,
    'toa_incident_solar_radiation': denorm_tisr,
    'total_cloud_cover': denorm_tcc,
    '2m_temperature': denorm_tmp,
}



# -*- coding: utf-8 -*-

vars2d = [
    '2m_temperature',
    '10m_u_component_of_wind', '10m_v_component_of_wind',
    'total_cloud_cover', 'total_precipitation',
    'toa_incident_solar_radiation',
    'temperature_850hPa',
]

vars3d = [
    'geopotential', 'temperature',
    'specific_humidity', 'relative_humidity',
    'u_component_of_wind', 'v_component_of_wind',
    'vorticity', 'potential_vorticity',
]

codes = {
    'geopotential': 'z',
    'temperature': 't',
    'temperature_850hPa': 't',
    'specific_humidity': 'q',
    'relative_humidity': 'r',
    'u_component_of_wind': 'u',
    'v_component_of_wind': 'v',
    'vorticity': 'vo',
    'potential_vorticity': 'pv',
    '2m_temperature': 't2m',
    '10m_u_component_of_wind': 'u10',
    '10m_v_component_of_wind': 'v10',
    'total_cloud_cover': 'tcc',
    'total_precipitation': 'tp',
    'toa_incident_solar_radiation': 'tisr',
}

code2var = {
    'z': 'geopotential',
    't': 'temperature',
    'q': 'specific_humidity',
    'r': 'relative_humidity',
    'u': 'u_component_of_wind',
    'v': 'v_component_of_wind',
    'vo': 'vorticity',
    'pv': 'potential_vorticity',
    't2m': '2m_temperature',
    'u10': '10m_u_component_of_wind',
    'v10': '10m_v_component_of_wind',
    'tcc': 'total_cloud_cover',
    'tp': 'total_precipitation',
    'tisr': 'toa_incident_solar_radiation',
}


def split_name(composite):
    if composite == 't2m' or composite == 'u10' or composite == 'v10' or composite == 'tcc' or composite == 'tp' or composite == 'tisr':
        return composite, ''
    else:
        if composite[:2] == 'vo' or composite[:2] == 'pv':
            return composite[:2], composite[2:]
        else:
            return composite[:1], composite[1:]
